@@ -240,8 +240,11 @@ class MGHArrayIO(protocol.IOProtocol):
                 'ti': read_bytes(file, dtype='>f4'),
             }
 
-            # ignore fov
-            fov = read_bytes(file, dtype='>f4')
+            # next parameter is the image FOV, which is not directly
+            # used so let's ignore it. unsure why it's in there at all.
+            # it's also not required in the freesurfer definition, so we'll
+            # use the read() function directly in case end-of-file is reached
+            file.read(np.dtype('>f4').itemsize)
  
             # update image-specific information
             if isinstance(arr, FramedImage):
@@ -361,7 +364,7 @@ class MGHArrayIO(protocol.IOProtocol):
             write_bytes(file, arr.metadata.get('te', 0.0), '>f4')
             write_bytes(file, arr.metadata.get('ti', 0.0), '>f4')
 
-            # compute FOV
+            # compute FOV (freesurfer actually reads this information though)
             volsize = pad_vector_length(arr.baseshape, 3, 1)
             fov = max(arr.geom.voxsize * volsize) if is_image else arr.shape[0]
             write_bytes(file, fov, '>f4')
@@ -436,11 +439,19 @@ class NiftiArrayIO(protocol.IOProtocol):
         filename : str
             Target file path.
         """
-        isimage = isinstance(arr, FramedImage)
-        matrix = arr.geom.vox2world.matrix if isimage else np.eye(4)
-        nii = self.nib.Nifti1Image(arr.data, matrix)
+        is_image = isinstance(arr, FramedImage)
+        matrix = arr.geom.vox2world.matrix if is_image else np.eye(4)
+
+        # convert to a valid output type (for now this is only bool but there are probably more)
+        type_map = {
+            np.bool8: np.uint8,
+        }
+        dtype_id = next((i for dt, i in type_map.items() if np.issubdtype(arr.dtype, dt)), None)
+        data = arr.data if dtype_id is None else arr.data.astype(dtype_id)
+
+        nii = self.nib.Nifti1Image(data, matrix)
         if is_image:
-            nii.header['pixdim'][1:4] = arr.voxsize
+            nii.header['pixdim'][1:4] = arr.geom.voxsize
         self.nib.save(nii, filename)
 
 
